"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatFiles = void 0;
const schematics_1 = require("@angular-devkit/schematics");
const path = require("path");
const rxjs_1 = require("rxjs");
const operators_1 = require("rxjs/operators");
function formatFiles(options = { skipFormat: false }) {
    let prettier;
    try {
        prettier = require('prettier');
    }
    catch (e) { }
    if (options.skipFormat) {
        return (0, schematics_1.noop)();
    }
    return (host, context) => {
        if (!prettier) {
            return host;
        }
        const files = new Set(host.actions
            .filter((action) => action.kind !== 'd' && action.kind !== 'r')
            .map((action) => ({
            path: action.path,
            content: action.content.toString(),
        })));
        if (files.size === 0) {
            return host;
        }
        return (0, rxjs_1.from)(files).pipe((0, operators_1.filter)((file) => host.exists(file.path)), (0, operators_1.mergeMap)((file) => __awaiter(this, void 0, void 0, function* () {
            const systemPath = path.join(process.cwd(), file.path);
            let options = {
                filepath: systemPath,
            };
            const resolvedOptions = yield prettier.resolveConfig(systemPath);
            if (resolvedOptions) {
                options = Object.assign(Object.assign({}, options), resolvedOptions);
            }
            const support = yield prettier.getFileInfo(systemPath, options);
            if (support.ignored || !support.inferredParser) {
                return;
            }
            try {
                host.overwrite(file.path, prettier.format(file.content, options));
            }
            catch (e) {
                context.logger.warn(`Could not format ${file.path} because ${e.message}`);
            }
        })), (0, operators_1.map)(() => host));
    };
}
exports.formatFiles = formatFiles;
